<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:oo="http://www.omnigroup.com/namespace/OmniOutliner/v3"
    xmlns:url="http://www.omnigroup.com/xslt/url"
    exclude-result-prefixes="oo"
>

    <xsl:output method="html"
              version="4.01"
              encoding="utf-8"
              doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
              indent="yes"/>

    <xsl:variable name="non-note-columns" select="oo:outline/oo:columns/oo:column[not(@is-note-column) or @is-note-column != 'yes']" />
    <xsl:strip-space elements="*" />

    <xsl:variable name="note-column-position">
        <xsl:for-each select="oo:outline/oo:columns">
          <xsl:if test="@is-note-column = 'yes'">
            <xsl:value-of select="position()"/>
          </xsl:if>
        </xsl:for-each>
    </xsl:variable>

    <xsl:variable name="outline-column-position">
        <xsl:for-each select="$non-note-columns">
          <xsl:if test="@is-outline-column = 'yes'">
            <xsl:value-of select="position()"/>
          </xsl:if>
        </xsl:for-each>
    </xsl:variable>

    <xsl:template match="/">
        <html xsl:exclude-result-prefixes="oo">
          <head>
            <!-- TODO: Also add a parameter for whether to put the styled document title in the body? -->
            <title><xsl:value-of select="/oo:outline/oo:outline-title/oo:text/oo:p/oo:run/oo:lit"/></title>
          </head>
          <body>
                <xsl:apply-templates select="oo:outline/oo:root/oo:item" />
          </body>
        </html>
    </xsl:template>

    <xsl:template match="oo:item">
        <xsl:variable name="current-level">
          <xsl:value-of select="count(ancestor-or-self::oo:item)"/>
        </xsl:variable>
        
        <!-- Figure out if we use an h or a p -->
        <xsl:variable name="element-name">
            <xsl:choose>
                <xsl:when test="$current-level &lt; 7">
                    <xsl:text>h</xsl:text>
                    <xsl:value-of select="$current-level"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>p</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <xsl:element name="{$element-name}">
            <xsl:apply-templates select="oo:values/*[number($outline-column-position)]"/>
        </xsl:element>
        <xsl:apply-templates select="oo:note"/>
        <xsl:apply-templates select="oo:cell"/>
        <xsl:apply-templates select="oo:children"/>
    </xsl:template>

    <xsl:template match="oo:note" >
<!--        <xsl:text>&#xa;</xsl:text> -->
            <xsl:apply-templates />
        <xsl:text>&#xa;&#xa;</xsl:text>
    </xsl:template>

    <xsl:template match="oo:note//oo:p" >
        <p>
            <xsl:apply-templates />
        </p>

    </xsl:template>

    <xsl:template match="oo:children">
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template name="cell-link">
        <xsl:param name="filename"/>
        <xsl:param name="href"/>
        <xsl:choose>
            <xsl:when test="$filename != '' and $href != ''">
                <span><a href="{$href}">
                    <xsl:if test="$filename != ''">
                        <img valign="middle" alt="" border="0" src="{$filename}" />
                    </xsl:if>
                    <xsl:value-of select="@name"/>
                </a></span>
            </xsl:when>
            <xsl:when test="$filename != ''">
                <span><a href="{$filename}"><xsl:value-of select="@name"/></a></span>
            </xsl:when>
            <xsl:when test="$href != ''">
                <span><a href="{$href}"><xsl:value-of select="@name"/></a></span>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="oo:cell" >
        
        <xsl:variable name="href">
            <xsl:value-of select="@href"/>
        </xsl:variable>
        
        <xsl:variable name="filename">
            <xsl:variable name="refid" select="@refid"/>
            
            <xsl:choose>
                
                <xsl:when test="function-available('url:encode')">
                    <xsl:value-of select="url:encode(/oo:outline/oo:attachments/oo:attachment[@id = $refid]/@href)"/>
                </xsl:when>
                
                <xsl:otherwise>
                    <xsl:value-of select="/oo:outline/oo:attachments/oo:attachment[@id = $refid]/@href"/>
                </xsl:otherwise>
                
            </xsl:choose>
        </xsl:variable>

        <xsl:choose>
            <xsl:when test="@type = 'image'"/>
            <xsl:when test="@type = 'movie'"/>
            <xsl:otherwise>
                <xsl:call-template name="cell-link" >
                    <xsl:with-param name="filename" select="$filename"/>
                    <xsl:with-param name="href" select="$href"/>
                </xsl:call-template>
            </xsl:otherwise>    
        </xsl:choose>
    </xsl:template>

    <xsl:template match="oo:style" />

</xsl:stylesheet>